;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "lab" "20250827.5"
  "An interface for GitLab."
  '((emacs       "27.1")
    (request     "0.3.2")
    (s           "1.10.0")
    (f           "0.20.0")
    (compat      "29.1.4.4")
    (promise     "1.1")
    (async-await "1.1"))
  :url "https://github.com/isamert/lab.el"
  :commit "a29b3ccadeab31b6582fedd0e35e5bf46c96fc64"
  :revdesc "a29b3ccadeab"
  :authors '(("Isa Mert Gurbuz" . "isamertgurbuz@gmail.com"))
  :maintainers '(("Isa Mert Gurbuz" . "isamertgurbuz@gmail.com")))
